# Oli

Oli is a one liner installer aimed at easing you with the installation of everything you need on different platforms.

## Installation

Run `pip install oli`

## Usage 

Run in your bash `oli`

## Programs

### Macos

-  Homebrew




